#-----------------------------------------------------------------------------
# Vehicle steering script.
#
# This script is meant to be applied to an entire animation sequence
# AFTER you have finished pushing the vehicle around manually, using
# the Xtrans and Ztrans dials or the Translation tool to set its
# position at various frames.  (Assuming normal spline behavior, so
# that Poser will curve the translational movement between your
# manually specified steps.)
#
# Select the vehicle then apply the script.
#
# After applying the script, the vehicle's Y rotation will then turn
# appropriately at each frame so that the vehicle appears to be
# steering into each turn.
#
# Copyright (c) 2003, David G. Drumright (ockham)
#-----------------------------------------------------------------------------

import poser
import math
Pi = 3.1415926535
PrevY=0.0

#-----------------------------------------------------------------------------


def Steer(thisframe):
    global PrevY

    scene = poser.Scene()
    thing = scene.CurrentActor()
    scene.SetFrame(thisframe) # Put everything into first position
    PresentOrigin = thing.WorldDisplacement() # Where is the object in first position?
    aheadframe = thisframe + 3 # second position is further ahead
    if aheadframe < scene.NumFrames():  # protect against end of list
       scene.SetFrame(aheadframe) # Put everything into the new position
       AheadOrigin = thing.WorldDisplacement() # Where is the object in new position?
       Xdist = AheadOrigin[0] - PresentOrigin[0]
       Zdist = AheadOrigin[2] - PresentOrigin[2]
       RawY = math.atan2(Zdist,-Xdist)  # Angle of vector from here to new
       scene.SetFrame(thisframe)  # Come back to where we are
       #Set the Y rotation of the object to anticipate this direction
       NewY = RawY * 180.0 / Pi - 90.0 # Turn to degrees
       alterParm = thing.Parameter("yRotate") # Rotate the object
       alterParm.SetValue(NewY) # Set Y rotation in degrees

#-----------------------------------------------------------------------------
# Find the figure
#-----------------------------------------------------------------------------

scene = poser.Scene()
for i in range(scene.NumFrames()):
  scene.SetFrame(i)
  Steer(i)

#-----------------------------------------------------------------------------
